- [🏠 HOME](./)
- [📖 Reading and ✏️ writing BVH files](./functionalities/readWrite/index.md)
- [🏃 Forward Kinematics](./functionalities/forwardKinematics/index.md)
- [🤚 BVH manipulation](./functionalities/manipulation/index.md)
- [🔪 BVH slicing](./functionalities/slicing/index.md)
- [👀 BVH viewer](./functionalities/viewer/index.md)
- [📋 Writing data to CSV files](./functionalities/csv/index.md)
- [🧑‍🔬 Simple Examples](./functionalities/examples/index.md)
- [👩‍🔬 Use Cases](./functionalities/useCases/index.md)